% LQGBOX -- A collection of routines to solve continuous and discrete-time
%           LQG problems. Written by Kjell Gustafsson
%
% Regulator
%
%    LQRC  - continuous-time linear quadratic regulator
%    LQRD  - discrete-time linear quadratic regulator
%
% Estimator
%
%    LQEC  - continuous-time linear quadratic estimator
%    LQED  - discrete-time linear quadratic estimator
%
% Complete controller
%
%    LQGC  - complete continuous-time controller from LQRC, LQEC, REFC results
%    LQGD  - complete discrete-time controller from  LQRD, LQED, REFD results
%    REFC  - reference input gain for continuous-time controller
%    REFD  - reference input gain for discrete-time controller
%
% Riccati equation solver
%
%    CARE  - general dispatch routine for continuous-time Riccati solvers
%    DARE  - general dispatch routine for discrete-time Riccati solvers
%
% Sampling
%
%    LQGSAMP  - sample loss function and continuous-time noise description
%
% Spectral factorization
%
%    SPFACTC  - continuous-time spectral factorization
%    SPFACTD  - discrete-time spectral factorization
%
% Miscellaneous
%
%    Two global variables (caretype and daretype) are needed. They are 
%    defined by executing LQGBOX. The dispatch routines CARE (and DARE)
%    examine these global variables and use their value to choose Riccati
%    equation solver. Currently, the default solver uses a method based on
%    an extended generalized eigenvalue problem. Check CARE and DARE to see 
%    what other solvers that are available.
%
%    Currently there is a name conflict between LQRD and LQED and similar 
%    routines in the control system toolbox. In addition, LQRC conflicts 
%    with a routine in the robust toolbox by Safanov.

% Kjell Gustafsson
% LastEditDate : Tue Apr  7 09:08:02 1992
% Copyright (c) 1990 by Kjell Gustafsson and Department of Automatic Control,
% Lund Institute of Technology, Lund, SWEDEN

global caretype
global daretype

caretype = 'gener';
daretype = 'gener';